@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2014 by the Quassel Project                        *
+ *   Copyright (C) 2005-2015 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -253,7 +253,6 @@ void BufferView::dropEvent(QDropEvent *event)
     if (bufferList.count() != 1)
         return QTreeView::dropEvent(event);
 
-    NetworkId networkId = bufferList[0].first;
     BufferId bufferId2 = bufferList[0].second;
 
     if (index.data(NetworkModel::ItemTypeRole) != NetworkModel::BufferItemType)
@@ -262,9 +261,6 @@ void BufferView::dropEvent(QDropEvent *event)
     if (index.data(NetworkModel::BufferTypeRole) != BufferInfo::QueryBuffer)
         return QTreeView::dropEvent(event);
 
-    if (index.data(NetworkModel::NetworkIdRole).value<NetworkId>() != networkId)
-        return QTreeView::dropEvent(event);
-
     BufferId bufferId1 = index.data(NetworkModel::BufferIdRole).value<BufferId>();
     if (bufferId1 == bufferId2)
         return QTreeView::dropEvent(event);
