@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2014 by the Quassel Project                        *
+ *   Copyright (C) 2005-2015 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,16 +20,15 @@
 
 #include "clearablelineedit.h"
 
+#include <QIcon>
 #include <QToolButton>
 #include <QStyle>
 
-#include "iconloader.h"
-
 ClearableLineEdit::ClearableLineEdit(QWidget *parent)
     : QLineEdit(parent)
 {
     clearButton = new QToolButton(this);
-    clearButton->setIcon(SmallIcon("edit-clear-locationbar-rtl"));
+    clearButton->setIcon(QIcon::fromTheme("edit-clear-locationbar-rtl", QIcon::fromTheme("edit-clear")));
 #ifndef Q_WS_QWS
     clearButton->setCursor(Qt::ArrowCursor);
 #endif
